Radio Beam: Tools for Beam IO and Manipulation
==============================================

Radio Beam is a simple toolkit for reading beam information from FITS headers
and manipulating beams.  Some example applications include:

 * Convolution and deconvolution
 * Unit conversion (Jy to/from K)
 * Handle sets of beams for spectral cubes with varying resolution between channels
 * Find the smallest common beam from a set of beams
 * Add the beam shape to a matplotlib plot

See the [documentation](https://radio-beam.readthedocs.io/en/latest/) for more information.

[![Build Status](https://travis-ci.org/radio-astro-tools/radio_beam.svg?branch=master)](https://travis-ci.org/radio-astro-tools/radio_beam)
